macro_rules! solutions {
($callback:ident) => { ... };
}Expand description
Enumerates all combinations of years and days, passing them to a callback macro.
Used by benchmark.rs, lib.rs, main.rs and test.rs.
macro_rules! solutions {
($callback:ident) => { ... };
}Enumerates all combinations of years and days, passing them to a callback macro.
Used by benchmark.rs, lib.rs, main.rs and test.rs.